-- only doing V6, duplicate in both tables
-- in the context of these commands, v4 is the original version, v5 is the new version for comparison
create table zdiff_stats_tb_dpr_v4 (
   percent_of_bins int,
   rangecat int,
   gvtype char(4),
   regime character varying(10),
   radar_id character varying(15),
   orbit integer,
   height float,
   meandiff float,
   diffstddev float,
   prstddev float,
   gvstddev float,
   prmean float,
   gvmean float,
   gvbinmax float,
   gvbinstddev float,
   numpts int,
   primary key (percent_of_bins, rangecat, gvtype, regime, radar_id, orbit, height)
);
delete from zdiff_stats_tb_dpr_v4;
\copy zdiff_stats_tb_dpr_v4 from '/home/tberendes/bulk_stats/comparison/StatsByDist_DPR_GR_Pct100_StdDevMode_V04A_DPR_NS_AltBB_S2Ku.unl' with delimiter '|'

create table zdiff_stats_tb_dpr_v5 (
   percent_of_bins int,
   rangecat int,
   gvtype char(4),
   regime character varying(10),
   radar_id character varying(15),
   orbit integer,
   height float,
   meandiff float,
   diffstddev float,
   prstddev float,
   gvstddev float,
   prmean float,
   gvmean float,
   gvbinmax float,
   gvbinstddev float,
   numpts int,
   primary key (percent_of_bins, rangecat, gvtype, regime, radar_id, orbit, height)
);
delete from zdiff_stats_tb_dpr_v5;
\copy zdiff_stats_tb_dpr_v5 from '/home/tberendes/bulk_stats/comparison/StatsByDist_DPR_GR_Pct100_StdDevMode_V05A_DPR_NS_AltBB_S2Ku.unl' with delimiter '|'

create table zdiff_stats_tb_dpr_v6 (
   percent_of_bins int,
   rangecat int,
   gvtype char(4),
   regime character varying(10),
   radar_id character varying(15),
   orbit integer,
   height float,
   meandiff float,
   diffstddev float,
   prstddev float,
   gvstddev float,
   prmean float,
   gvmean float,
   gvbinmax float,
   gvbinstddev float,
   numpts int,
   primary key (percent_of_bins, rangecat, gvtype, regime, radar_id, orbit, height)
);
delete from zdiff_stats_tb_dpr_v6;
\copy zdiff_stats_tb_dpr_v6 from '/home/tberendes/bulk_stats/comparison/StatsByDist_DPR_GR_Pct100_StdDevMode_V06A_DPR_NS_AltBB_S2Ku.unl' with delimiter '|'

--------------------------------------------------------------------------------------------

-- Now that the output from the IDL runs have been loaded to the database tables,
-- run some statistics and/or produce output files needed as input to the
-- IDL procedures to plot site biases on a map or plot time series of site
-- specific reflectivity bias.

-- merge the Ku-adjusted GR diffs in the two versions into a single temp table,
-- matched one-to-one by primary key attributes

select a.percent_of_bins, a.rangecat, a.gvtype, a.regime, a.radar_id, a.orbit, a.height, a.meandiff as meandiffv4, b.meandiff as meandiffv5, 
a.numpts as numptsv4, b.numpts as numptsv5 into temp merged_diffs_4_5 from zdiff_stats_tb_dpr_v4 a join zdiff_stats_tb_dpr_v5 b 
USING (percent_of_bins, rangecat, gvtype , regime, radar_id, orbit, height);

select count(*) from merged_diffs_4_5;

select a.percent_of_bins, a.rangecat, a.gvtype, a.regime, a.radar_id, a.orbit, a.height, a.meandiff as meandiffv5, b.meandiff as meandiffv6,
a.numpts as numptsv5, b.numpts as numptsv6 into temp merged_diffs_5_6 from zdiff_stats_tb_dpr_v5 a join zdiff_stats_tb_dpr_v6 b
USING (percent_of_bins, rangecat, gvtype , regime, radar_id, orbit, height);

select count(*) from merged_diffs_5_6;

select a.percent_of_bins, a.rangecat, a.gvtype, a.regime, a.radar_id, a.orbit, a.height, a.meandiff as meandiffv4, b.meandiff as meandiffv6,
a.numpts as numptsv4, b.numpts as numptsv6 into temp merged_diffs_4_6 from zdiff_stats_tb_dpr_v4 a join zdiff_stats_tb_dpr_v6 b
USING (percent_of_bins, rangecat, gvtype , regime, radar_id, orbit, height);

select count(*) from merged_diffs_4_6;

-- output above info to delimited table, with lat/lon information,
-- in the column order needed for the external IDL program to plot
-- the biases on a map
-- We don't set the tuples_only (\t) and align (\a)
-- options again, as these are 'toggle' options and would reverse their state, messing
-- up the output file format.

-- be sure to remove the output file before doing this or it will just append output to existing file
-- also remember to adjust orbits to common range between versions

-- assumed that the first column is the "new" value and the second column is the "old" value
-- the (-1) in the following is due to the difference being defined as PR-GV in the IDL code to compute stats
-- and the idl plotting program plots the other way around
\t \a 
\o /home/tberendes/bulk_stats/comparison/GR_DPR_Bias_s2ku_v4_v5_Pct100.unl \\
select radar_id, round((sum(meandiffv5*numptsv5)/sum(numptsv5))*100)/100*(-1) as meandiff_v5, sum(numptsv5) as total_v5, 
round((sum(meandiffv4*numptsv4)/sum( numptsv4))*100)/100*(-1) as meandiff_v4, sum(numptsv4) as total_v4, f.latitude, 
f.longitude from merged_diffs_4_5 a, fixed_instrument_location f where regime='S_above' and numptsv4>5 and numptsv5>5
 and percent_of_bins=100 and a.radar_id=f.instrument_id and a.radar_id between 'KAAA' and 'KWAI' and a.radar_id != 'KCAE'
 and orbit>=2977 and orbit<=18020 group by radar_id, latitude, longitude order by radar_id;
\o

\o /home/tberendes/bulk_stats/comparison/GR_DPR_Bias_s2ku_v5_v6_Pct100.unl \\
select radar_id, round((sum(meandiffv6*numptsv6)/sum(numptsv6))*100)/100*(-1) as meandiff_v6, sum(numptsv6) as total_v6,
round((sum(meandiffv5*numptsv5)/sum( numptsv5))*100)/100*(-1) as meandiff_v5, sum(numptsv5) as total_v5, f.latitude,
f.longitude from merged_diffs_5_6 a, fixed_instrument_location f where regime='S_above' and numptsv5>5 and numptsv6>5
 and percent_of_bins=100 and a.radar_id=f.instrument_id and a.radar_id between 'KAAA' and 'KWAI' and a.radar_id != 'KCAE'
 and orbit>=2977 and orbit<=18020 group by radar_id, latitude, longitude order by radar_id;
\o

\o /home/tberendes/bulk_stats/comparison/GR_DPR_Bias_s2ku_v4_v6_Pct100.unl \\
select radar_id, round((sum(meandiffv6*numptsv6)/sum(numptsv6))*100)/100*(-1) as meandiff_v6, sum(numptsv6) as total_v6,
round((sum(meandiffv4*numptsv4)/sum( numptsv4))*100)/100*(-1) as meandiff_v4, sum(numptsv4) as total_v4, f.latitude,
f.longitude from merged_diffs_4_6 a, fixed_instrument_location f where regime='S_above' and numptsv4>5 and numptsv6>5
 and percent_of_bins=100 and a.radar_id=f.instrument_id and a.radar_id between 'KAAA' and 'KWAI' and a.radar_id != 'KCAE'
 and orbit>=2977 and orbit<=18020 group by radar_id, latitude, longitude order by radar_id;
\o

-------------------------------------------------------------------------------------------
-- set up output for time series plots

-- be sure to remove the output file before doing this or it will just append output to existing file

\f '|' \o /home/tberendes/bulk_stats/comparison/event_best_diffs_v4_Pct100s2ku.txt \\select a.radar_id,
date_trunc('day',b.overpass_time at time zone 'UTC') as event_date, round((sum(meandiff*numpts)/sum(numpts))*100)/100
 as zbias, sum(numpts) as total, round((sum(diffstddev*numpts)/sum(numpts))*100)/100 as bias_stddev from
zdiff_stats_tb_dpr_v4 a, overpass_event b where regime='S_above' and a.orbit=b.orbit and a.radar_id=b.radar_id
and b.sat_id='GPM' and percent_of_bins=100 group by 1,2 order by 1,2;
\o

\f '|' \o /home/tberendes/bulk_stats/comparison/event_best_diffs_v5_Pct100s2ku.txt \\select a.radar_id,
date_trunc('day',b.overpass_time at time zone 'UTC') as event_date, round((sum(meandiff*numpts)/sum(numpts))*100)/100
 as zbias, sum(numpts) as total, round((sum(diffstddev*numpts)/sum(numpts))*100)/100 as bias_stddev from
zdiff_stats_tb_dpr_v5 a, overpass_event b where regime='S_above' and a.orbit=b.orbit and a.radar_id=b.radar_id
and b.sat_id='GPM' and percent_of_bins=100 group by 1,2 order by 1,2;
\o

\f '|' \o /home/tberendes/bulk_stats/comparison/event_best_diffs_v6_Pct100s2ku.txt \\select a.radar_id,
date_trunc('day',b.overpass_time at time zone 'UTC') as event_date, round((sum(meandiff*numpts)/sum(numpts))*100)/100
 as zbias, sum(numpts) as total, round((sum(diffstddev*numpts)/sum(numpts))*100)/100 as bias_stddev from
zdiff_stats_tb_dpr_v6 a, overpass_event b where regime='S_above' and a.orbit=b.orbit and a.radar_id=b.radar_id
and b.sat_id='GPM' and percent_of_bins=100 group by 1,2 order by 1,2;
\o

drop table zdiff_stats_tb_dpr_v4;
drop table zdiff_stats_tb_dpr_v5;
drop table zdiff_stats_tb_dpr_v6;

